PinnedBun@bunjavascriptDec 2, 2025Bun is joining Anthropic!Bun is joining AnthropicFrom bun.com7652.4K12K4.7M
Bun@bunjavascriptOct 28claude.ai switched from oxfmt to bun fmt Formatting in CI got 1.7x faster151755516K
Bun@bunjavascriptOct 27claude.ai switched from `oxlint` to `bun lint` ci got 22s fasterread image descriptionALT31421.1K37K
Bun@bunjavascriptOct 27Last week, we published 3 security advisories including Brotli, tls certificates, and quic As future hardening, we will replace most of Bun’s C/C++ dependencies with our own safe Rust implementation. Starting with libarchiveReplace libarchive with a tar reader and writer in safe Rust by dylan-conway · Pull Request #46638...From github.com273053922K
Bun@bunjavascriptOct 27claude.ai switched from TypeScript 7 to `bun check` type-checking got 69s fasterread image descriptionALT394298033K